import { BundledLanguage, CodeToTokensWithThemesOptions, BundledTheme, HighlighterCore } from 'shiki';

interface MountPlainShikiOptions {
    /**
     * @description Language of the code to be highlighted.
     *
     * @requires
     */
    lang: BundledLanguage;
    /**
     * @description Themes of the code to be highlighted.
     *
     * @default {light:"min-light",dark:"min-dark"}
     */
    themes?: CodeToTokensWithThemesOptions<BundledLanguage, BundledTheme>["themes"];
    /**
     * @description Name of default theme.
     *
     * @default "light"
     */
    defaultTheme?: string | false;
    /**
     * @description Root element selector corresponding to the theme.
     *
     * @default `.${theme}`
     */
    selector?: (theme: string) => string;
    /**
     * @description Root element selector with default theme.
     *
     * @default ":root"
     */
    defaultSelector?: string;
    /**
     * @description Whether to listen for element update events and automatic rendering.
     *
     * @default true
     */
    watch?: boolean;
    /**
     * @description Throttle delay in updating when `watch: true`.
     *
     * @default 33.4
     */
    delay?: number;
}
type CreatePlainShikiReturns = ReturnType<typeof createPlainShiki>;
declare function createPlainShiki(shiki: HighlighterCore): {
    readonly isSupported: boolean;
    mount: (el: HTMLElement, options: MountPlainShikiOptions) => {
        dispose: (this: unknown) => boolean;
        update: () => void;
    };
};

export { type CreatePlainShikiReturns, type MountPlainShikiOptions, createPlainShiki };
